@@ -147,7 +147,7 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"|test_user_1_|%d|en|%s|0|0' % (catalog.getCounter(
+        self.assertEqual('"|test_user_1_|%d|en|%s|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
@@ -162,7 +162,7 @@ class TestProfileWithCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"|test_user_1_|%d|en|%s|0|1' % (catalog.getCounter(
+        self.assertEqual('"|test_user_1_|%d|en|%s|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
 
         # Request the authenticated page
@@ -181,7 +181,7 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"|test_user_1_|%d|en|%s|0' % (catalog.getCounter(
+        self.assertEqual('"|test_user_1_|%d|en|%s' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
@@ -227,7 +227,7 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"||%d|en|%s|0|0' % (catalog.getCounter(
+        self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
@@ -244,7 +244,7 @@ class TestProfileWithCaching(unittest.TestCase):
         # This should use cacheInBrowser
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
+        self.assertEqual('"||%d|en|%s' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
@@ -264,7 +264,7 @@ class TestProfileWithCaching(unittest.TestCase):
         self.assertIn(testText, browser.contents)
         self.assertEqual('max-age=0, must-revalidate, private',
                          browser.headers['Cache-Control'])
-        self.assertEqual('"||%d|en|%s|0' % (catalog.getCounter(
+        self.assertEqual('"||%d|en|%s' % (catalog.getCounter(
         ), skins_tool.default_skin), _normalize_etag(browser.headers['ETag']))
         self.assertGreater(now, dateutil.parser.parse(
             browser.headers['Expires']))
